@@ -1,10 +1,10 @@
 {%- import "macros.kt" as kt -%}
 {%- let inner_type = self.inner() %}
 {%- let outer_type = self.outer() %}
-{%- let inner_type_name = inner_type|type_kt %}
+{%- let inner_type_name = inner_type|type_name %}
 {%- let canonical_type_name = outer_type|canonical_name %}
 
-// Helper functions for passing values of type {{ outer_type|type_kt }}
+// Helper functions for passing values of type {{ outer_type|type_name }}
 internal fun lower{{ canonical_type_name }}(v: {{ inner_type_name }}?): RustBuffer.ByValue {
     return lowerIntoRustBuffer(v) { v, buf ->
         write{{ canonical_type_name }}(v, buf)
@@ -16,7 +16,7 @@ internal fun write{{ canonical_type_name }}(v: {{ inner_type_name }}?, buf: Rust
         buf.putByte(0)
     } else {
         buf.putByte(1)
-        {{ "v"|write_kt("buf", inner_type) }}
+        {{ "v"|write_var("buf", inner_type) }}
     }
 }
 
@@ -30,5 +30,5 @@ internal fun read{{ canonical_type_name }}(buf: ByteBuffer): {{ inner_type_name
     if (buf.get().toInt() == 0) {
         return null
     }
-    return {{ "buf"|read_kt(inner_type) }}
-}
\ No newline at end of file
+    return {{ "buf"|read_var(inner_type) }}
+}
