@@ -1,10 +1,10 @@
 {%- import "macros.kt" as kt -%}
 {%- let inner_type = self.inner() %}
 {%- let outer_type = self.outer() %}
-{%- let inner_type_name = inner_type|type_kt %}
+{%- let inner_type_name = inner_type|type_name %}
 {%- let canonical_type_name = outer_type|canonical_name %}
 
-// Helper functions for passing values of type {{ outer_type|type_kt }}
+// Helper functions for passing values of type {{ outer_type|type_name }}
 internal fun lower{{ canonical_type_name }}(v: List<{{ inner_type_name }}>): RustBuffer.ByValue {
     return lowerIntoRustBuffer(v) { v, buf ->
         write{{ canonical_type_name }}(v, buf)
@@ -14,7 +14,7 @@ internal fun lower{{ canonical_type_name }}(v: List<{{ inner_type_name }}>): Rus
 internal fun write{{ canonical_type_name }}(v: List<{{ inner_type_name }}>, buf: RustBufferBuilder) {
     buf.putInt(v.size)
     v.forEach {
-        {{ "it"|write_kt("buf", inner_type) }}
+        {{ "it"|write_var("buf", inner_type) }}
     }
 }
 
@@ -27,6 +27,6 @@ internal fun lift{{ canonical_type_name }}(rbuf: RustBuffer.ByValue): List<{{ in
 internal fun read{{ canonical_type_name }}(buf: ByteBuffer): List<{{ inner_type_name }}> {
     val len = buf.getInt()
     return List<{{ inner_type_name }}>(len) {
-        {{ "buf"|read_kt(inner_type) }}
+        {{ "buf"|read_var(inner_type) }}
     }
-}
\ No newline at end of file
+}
