@@ -1,5 +1,10 @@
 {% import "macros.kt" as kt %}
 {%- let func = self.inner() %}
+{%- match func.throws() -%}
+{%- when Some with (throwable) %}
+@Throws({{ throwable|exception_name }}::class)
+{%- else -%}
+{%- endmatch %}
 {%- match func.return_type() -%}
 {%- when Some with (return_type) %}
 
