@@ -5,8 +5,8 @@
 class FfiConverter{{ canonical_type_name }}(FfiConverterUsingByteBuffer):
     @staticmethod
     def _write(value, buf):
-        FfiConverterSequence._write(value, buf, lambda v, buf: {{ "v"|write_py("buf", inner_type) }})
+        FfiConverterSequence._write(value, buf, lambda v, buf: {{ "v"|write_var("buf", inner_type) }})
 
     @staticmethod
     def _read(buf):
-        return FfiConverterSequence._read(buf, lambda buf: {{ "buf"|read_py(inner_type) }})
+        return FfiConverterSequence._read(buf, lambda buf: {{ "buf"|read_var(inner_type) }})
