@@ -32,6 +32,10 @@ pub(super) enum Attribute {
     SelfType(SelfType),
     Threadsafe, // N.B. the `[Threadsafe]` attribute is deprecated and will be removed
     Throws(String),
+    // `[External="crate_name"]` - We can `use crate_name::...` for the type.
+    External(String),
+    // Something hand-written in this crate which wraps a primitive type.
+    Wrapped,
 }
 
 impl Attribute {
@@ -57,6 +61,7 @@ impl TryFrom<&weedle::attribute::ExtendedAttribute<'_>> for Attribute {
                 "Enum" => Ok(Attribute::Enum),
                 "Error" => Ok(Attribute::Error),
                 "Threadsafe" => Ok(Attribute::Threadsafe),
+                "Wrapped" => Ok(Attribute::Wrapped),
                 _ => anyhow::bail!("ExtendedAttributeNoArgs not supported: {:?}", (attr.0).0),
             },
             // Matches assignment-style attributes like ["Throws=Error"]
@@ -65,6 +70,7 @@ impl TryFrom<&weedle::attribute::ExtendedAttribute<'_>> for Attribute {
                     "Name" => Ok(Attribute::Name(name_from_id_or_string(&identity.rhs))),
                     "Throws" => Ok(Attribute::Throws(name_from_id_or_string(&identity.rhs))),
                     "Self" => Ok(Attribute::SelfType(SelfType::try_from(&identity.rhs)?)),
+                    "External" => Ok(Attribute::External(name_from_id_or_string(&identity.rhs))),
                     _ => anyhow::bail!(
                         "Attribute identity Identifier not supported: {:?}",
                         identity.lhs_identifier.0
@@ -391,6 +397,55 @@ impl TryFrom<&weedle::attribute::IdentifierOrString<'_>> for SelfType {
     }
 }
 
+/// Represents UDL attributes that might appear on a typedef
+///
+/// This supports the `[External="crate_name"]` and `[Wrapped]` attributes for types.
+#[derive(Debug, Clone, Hash, Default)]
+pub(super) struct TypedefAttributes(Vec<Attribute>);
+
+impl TypedefAttributes {
+    pub(super) fn get_crate_name(&self) -> String {
+        self.0
+            .iter()
+            .find_map(|attr| match attr {
+                Attribute::External(crate_name) => Some(crate_name.clone()),
+                _ => None,
+            })
+            .expect("must have a crate name")
+    }
+
+    pub(super) fn is_wrapped(&self) -> bool {
+        self.0
+            .iter()
+            .any(|attr| matches!(attr, Attribute::Wrapped { .. }))
+    }
+}
+
+impl TryFrom<&weedle::attribute::ExtendedAttributeList<'_>> for TypedefAttributes {
+    type Error = anyhow::Error;
+    fn try_from(
+        weedle_attributes: &weedle::attribute::ExtendedAttributeList<'_>,
+    ) -> Result<Self, Self::Error> {
+        let attrs = parse_attributes(weedle_attributes, |attr| match attr {
+            Attribute::External { .. } | Attribute::Wrapped => Ok(()),
+            _ => bail!(format!("{:?} not supported for typedefs", attr)),
+        })?;
+        Ok(Self(attrs))
+    }
+}
+
+impl<T: TryInto<TypedefAttributes, Error = anyhow::Error>> TryFrom<Option<T>>
+    for TypedefAttributes
+{
+    type Error = anyhow::Error;
+    fn try_from(value: Option<T>) -> Result<Self, Self::Error> {
+        match value {
+            None => Ok(Default::default()),
+            Some(v) => v.try_into(),
+        }
+    }
+}
+
 #[cfg(test)]
 mod test {
     use super::*;
@@ -653,4 +708,41 @@ mod test {
             "ByRef not supported for interface definition"
         );
     }
+
+    #[test]
+    fn test_typedef_attribute() {
+        let (_, node) = weedle::attribute::ExtendedAttributeList::parse("[Wrapped]").unwrap();
+        let attrs = TypedefAttributes::try_from(&node).unwrap();
+        assert!(attrs.is_wrapped());
+
+        let (_, node) =
+            weedle::attribute::ExtendedAttributeList::parse("[External=crate_name]").unwrap();
+        let attrs = TypedefAttributes::try_from(&node).unwrap();
+        assert!(!attrs.is_wrapped());
+        assert_eq!(attrs.get_crate_name(), "crate_name");
+    }
+
+    #[test]
+    fn test_typedef_attributes_malformed() {
+        let (_, node) = weedle::attribute::ExtendedAttributeList::parse("[Wrapped=foo]").unwrap();
+        let err = TypedefAttributes::try_from(&node).unwrap_err();
+        assert_eq!(
+            err.to_string(),
+            "Attribute identity Identifier not supported: \"Wrapped\""
+        );
+
+        let (_, node) = weedle::attribute::ExtendedAttributeList::parse("[External]").unwrap();
+        let err = TypedefAttributes::try_from(&node).unwrap_err();
+        assert_eq!(
+            err.to_string(),
+            "ExtendedAttributeNoArgs not supported: \"External\""
+        );
+    }
+
+    #[test]
+    fn test_other_attributes_not_supported_for_typedef() {
+        let (_, node) = weedle::attribute::ExtendedAttributeList::parse("[ByRef]").unwrap();
+        let err = TypedefAttributes::try_from(&node).unwrap_err();
+        assert_eq!(err.to_string(), "ByRef not supported for typedefs");
+    }
 }
