@@ -116,11 +116,11 @@ pub(super) fn convert_default_value(
             Literal::Enum(s.0.to_string(), type_.clone())
         }
         (weedle::literal::DefaultValue::Null(_), Type::Optional(_)) => Literal::Null,
-        (_, Type::Optional(inner_type)) => convert_default_value(default_value, &inner_type)?,
+        (_, Type::Optional(inner_type)) => convert_default_value(default_value, inner_type)?,
 
         // We'll ensure the type safety in the convert_* number methods.
-        (weedle::literal::DefaultValue::Integer(i), _) => convert_integer(&i, type_)?,
-        (weedle::literal::DefaultValue::Float(i), _) => convert_float(&i, type_)?,
+        (weedle::literal::DefaultValue::Integer(i), _) => convert_integer(i, type_)?,
+        (weedle::literal::DefaultValue::Float(i), _) => convert_float(i, type_)?,
 
         _ => bail!("No support for {:?} literal yet", default_value),
     })
